@@ -1,12 +1,12 @@
 package Catalyst::Model::CDBI::Plain;
 
 use strict;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use base qw[Class::DBI Catalyst::Base];
 
 sub new {
     my ( $class, $c ) = @_;
-    return Catalyst::Base::new( $class, $c );
+    return Catalyst::Base->new( $class, $c );
 }
 
 1;
@@ -55,6 +55,16 @@ module can be used with existing C<Class::DBI> classes, so that they can
 be used with Catalyst, or as a way of writing CDBI-based Model classes
 within Catalyst.
 
+=head2 METHODS 
+
+=over 4
+
+=item new
+
+Overrides the constructor to create a Catalyst::Base object, rather than a CDBI object.
+
+=back
+
 =head1 AUTHOR
 
 Jesse Sheidlower C<E<lt>jester@panix.comE<gt>>
